==> fourcircle_0.0.1.orig.tar.gz: fourcircle-0.0.1.orig/src/venuedetails.cpp <==
#include "venuedetails.h"
#include "ui_venuedetails.h"
#include "foursquarecomm.h"
#include <QDebug>

VenueDetails::VenueDetails(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::VenueDetails)
{
    ui->setupUi(this);

    #if defined(Q_WS_MAEMO_5)
    this->setAttribute(Qt::WA_Maemo5StackedWindow);
    #endif
    this->setWindowFlags(this->windowFlags()| Qt::Window);

    QFont font;
    font.setPointSize(ui->lblName->font().pointSize()+4);
    font.setBold(true);
    ui->lblName->setFont(font);

    fsc = FoursquareComm::instance();
    ic = new ImageCache(this);
}

VenueDetails::~VenueDetails()
{
    delete ui;
}

void VenueDetails::setVenue(f_venue v)
{
    this->venue = v;
    ui->lblName->setText(v.name);
    this->setLabelText(ui->lblCheckinCount,QString::number(v.checkinsCount));
    this->setLabelText(ui->lblCity,v.location.city);
    this->setLabelText(ui->lblCrossStreet,v.location.crossStreet);
    this->setLabelText(ui->lblDistance,QString::number(v.location.distance));
    this->setLabelText(ui->lblHereNow,QString::number(v.hereNowCount));
    this->setLabelText(ui->lblPostalCode,v.location.postalCode);
    this->setLabelText(ui->lblState,v.location.state);
    this->setLabelText(ui->lblStreet,v.location.address);
    this->setLabelText(ui->lblUserCount,QString::number(v.usersCount));
    this->setLabelText(ui->lblDescription,v.description);
    if(!v.extendedInfo)
      this->setVenue(fsc->getVenue(venue.id));
    else
    {
        this->setLabelText(ui->lblMayorName,v.mayor.firstName+" "+v.mayor.lastName);
        QImage image(ic->getImage(v.mayor.photo));
        ui->lblMayorImg->setPixmap(QPixmap::fromImage(image));
        ui->lblMayorCheckinCount->setText(QString::number(v.mayorCheckinCount)+" checkins");
    }
}

void VenueDetails::setLabelText(QLabel * l, QString s)
{
    if(s!="")
    {
        l->setText(s);
        l->show();
    }
    else
        l->hide();
}


void VenueDetails::on_pbCheckin_clicked()
{
    cd = new CheckinDetails();
    cd->setVenue(this->venue);
    cd->exec();

    qDebug() << "on_pbCheckin_clicked done";
}

==> fourcircle_0.0.1-5.tar.gz: fourcircle-0.0.1/src/venuedetails.cpp <==
#include "venuedetails.h"
#include "ui_venuedetails.h"
#include "foursquarecomm.h"
#include <QDebug>
#include <QtConcurrentRun>
#include <QThread>
// #include <qtconcurrentrun.h>

VenueDetails::VenueDetails(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::VenueDetails)
{
    ui->setupUi(this);

    #if defined(Q_WS_MAEMO_5)
    this->setAttribute(Qt::WA_Maemo5StackedWindow);
    #endif
    this->setWindowFlags(this->windowFlags()| Qt::Window);

    QFont font;
    font.setPointSize(ui->lblName->font().pointSize()+4);
    font.setBold(true);
    ui->lblName->setFont(font);

    fsc = FoursquareComm::instance();
    ic = new ImageCache(this);
}

VenueDetails::~VenueDetails()
{
    delete ui;
}

void VenueDetails::setVenue(f_venue v)
{
    this->venue = v;
    ui->lblName->setText(v.name);
    this->setLabelText(ui->lblCheckinCount,QString::number(v.checkinsCount));
    this->setLabelText(ui->lblCity,v.location.city);
    this->setLabelText(ui->lblCrossStreet,v.location.crossStreet);
    this->setLabelText(ui->lblDistance,QString::number(v.location.distance));
    this->setLabelText(ui->lblHereNow,QString::number(v.hereNowCount));
    this->setLabelText(ui->lblPostalCode,v.location.postalCode);
    this->setLabelText(ui->lblState,v.location.state);
    this->setLabelText(ui->lblStreet,v.location.address);
    this->setLabelText(ui->lblUserCount,QString::number(v.usersCount));
    this->setLabelText(ui->lblDescription,v.description);
    if(!v.extendedInfo)
    {
        connect(fsc,SIGNAL(venueReady(f_venue)),this,SLOT(setVenue(f_venue)));
        //extern void getVenueDetails(QString id);
        //QFuture<void> f1 = QtConcurrent::run(getVenueDetails,QString(venue.id));
        //extern f_venue getVenue(QString);
        //QFuture<f_venue> f1 = QtConcurrent::run(fsc,getVenue,venue.id);
        //dit in de achtergrond :
        this->setVenue(fsc->getVenue(venue.id));
    }
    else
    {
        this->setLabelText(ui->lblMayorName,v.mayor.firstName+" "+v.mayor.lastName);
        QImage image(ic->getImage(v.mayor.photo));
        ui->lblMayorImg->setPixmap(QPixmap::fromImage(image));
        ui->lblMayorCheckinCount->setText(QString::number(v.mayorCheckinCount)+" checkins");
    }
}

void VenueDetails::setLabelText(QLabel * l, QString s)
{
    if(s!="")
    {
        l->setText(s);
        l->show();
    }
    else
        l->hide();
}


void VenueDetails::on_pbCheckin_clicked()
{
    cd = new CheckinDetails();
    cd->setVenue(this->venue);
    cd->exec();

    qDebug() << "on_pbCheckin_clicked done";
}
void VenueDetails::getVenueDetails(QString id)
{
    setVenue(fsc->getVenue(id));
}
